<template>
  <a-modal :title='title' :width='500' :visible='visible' :maskClosable='false' :confirmLoading='confirmLoading'
           :okButtonProps='{ props: {disabled: disableSubmit} }' @ok='handleOk' @cancel='handleCancel' cancelText='关闭'>
    <a-spin :spinning='confirmLoading'>
      <a-form :form='form'>

        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='参数编号' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入参数编号' allow-clear
                       :maxLength='10' v-decorator="[ 'parameterCode', validatorRules.parameterCode]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='参数名称' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入参数名称' allow-clear
                       :maxLength='20' v-decorator="[ 'parameterName', validatorRules.parameterName]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='参数描述' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入参数描述' allow-clear
                       :maxLength='50' v-decorator="[ 'parameterDescribe', validatorRules.parameterDescribe]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='数据源地址' :labelCol='labelCol' :wrapperCol='{xs: { span: 24 },sm: { span: 14 }}'>
              <a-input-search style='display: inline-block' :disabled='disableSubmit' readOnly='true'
                              placeholder='请输入数据源地址' allow-clear
                              :maxLength='50' v-decorator="[ 'address', validatorRules.address]"
                              enter-button @search='onSearch' />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
    <template slot='footer' v-if='disableSubmit == false'>
      <a-button :style="{ marginRight: '8px' }" @click='handleCancel'>关闭</a-button>
      <a-button @click='handleOk' type='primary'>确定</a-button>
    </template>

    <parameter-address ref='modalAddress' @ok='modalFormOk' :server-id='serverId' />

  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { httpAction, getAction } from '@/api/manage'
import ParameterAddress from './select/ParameterAddress'
import { loadCategoryData } from '../../../../api/api'


export default {
  components: { ParameterAddress },
  props: [
    'serverId'
  ],
  name: 'EmptyParameterModel',
  data() {
    return {
      indexStyle: false,
      readWriteType: '',
      parameterType: '只读',
      title: '',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 7 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 14 }
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      readWriteTypeList: [],
      parameterTypeList: [
        { key: '只读' },
        { key: '读写' }
      ],
      validatorRules: {
        parameterName: {
          rules: [{
            required: true,
            message: '请输入参数组名称'
          }]
        },
        parameterCode: {
          rules: [{
            required: true,
            message: '请输入参数组编号'
          }]
        }
      },
      url: {
        add: '/empty/parameter/add',
        edit: '/empty/parameter/edit',
        dataType: '/equipment/queryDataType'
      },
      disableSubmit: false
    }
  },

  methods: {
    onSearch() {
      this.$refs.modalAddress.visible1 = true
    },
    add() {
      this.edit({})
    },
    modalFormOk(record) {
      let model = Object.assign({}, record)
      this.$nextTick(() => {
        this.form.setFieldsValue({
          parameterDescribe: model.describe,
          address: model.default1
        })
      })
      this.readWriteType = model.dataType
    },
    edit(record) {
      // 查询系统类型
      getAction(this.url.dataType, { id: this.serverId }).then((res) => {
        if (res.success) {
          this.readWriteTypeList = res.result
          this.readWriteType = this.readWriteTypeList[0].default1
        }
      })
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'parameterCode', 'parameterName', 'parameterDescribe', 'address'))
      })
      this.readWriteType = this.model.parameterType
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, values)
          let obj
          formData.parameterType = this.readWriteType
          formData.readWriteType = this.parameterType
          if (!this.model.id) {
            formData.type = 1
            formData.equipmentId = this.serverId
            obj = httpAction(this.url.add, formData, 'post')
          } else {
            obj = httpAction(this.url.edit, formData, 'put')
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok', res.result)
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        }
      })
    },
    handleCancel() {
      this.close()
    }
  }
}
</script>

